<?php
/**
 * Magento
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/osl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@magentocommerce.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade Magento to newer
 * versions in the future. If you wish to customize Magento for your
 * needs please refer to http://www.magentocommerce.com for more information.
 *
 * @copyright   Copyright (c) 2014 X.commerce, Inc. (http://www.magentocommerce.com)
 * @license     http://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 */

namespace Magento\Mtf\Util\Filter;

/**
 * Base class filters out classes that are affected by specified tag.
 */
class AbstractClassTag extends AbstractFilterTag implements FilterInterface
{
    /**
     * Filters out class.
     *
     * @param string $class
     * @return bool
     */
    public function apply($class)
    {
        $tags = $this->getClassTags($class);
        return $this->processApply($tags);
    }

    /**
     * Return constants of class.
     *
     * @param string $class
     * @return array
     */
    protected function getClassTags($class)
    {
        $reflection  = new \ReflectionClass($class);
        $constants = $reflection->getConstants();
        $result = [];

        foreach ($constants as $name => $constant) {
            $name = strtolower($name);
            $values = empty($constant) ? [] : explode(',', $constant);

            $result[$name] = array_map('trim', $values);
        }

        return $result;
    }
}
